@@ -28,7 +28,7 @@ and its test function modules every time.
 from signal import SIGHUP
 
 from plib.classes import PTCPServer
-from plib.stdlib.SigSocketServer import BaseRequestHandler
+from plib.stdlib.io.blocking import BaseRequestHandler
 
 import emailfilter
 from emailfilterdefs import *
@@ -41,7 +41,10 @@ class EMailFilterHandler(BaseRequestHandler):
     bufsize = EMAILFILTER_BUFSIZE
     
     def process_data(self):
-        result = emailfilter.main(self.read_data)
+        try:
+            result = emailfilter.main(self.read_data)
+        except:
+            result = self.read_data
         self.start(result)
 
 class EMailFilterServer(PTCPServer):
